﻿-----------------------------------------------------------------------
-- Locale
-----------------------------------------------------------------------
local L = AceLibrary("AceLocale-2.2"):new("Violation: HealingTaken")

L:RegisterTranslations("enUS", function() return {
	["Healing taken"] = true,
	["HT"] = true,
} end)

L:RegisterTranslations("zhCN", function() return {
	["Healing taken"] = "接受治疗",
	["HT"] = "接受治疗(HT)",
} end)

L:RegisterTranslations("zhTW", function() return {
	["Healing taken"] = "承受治療",
	["HT"] = "承受治療(HT)",
} end)

L:RegisterTranslations("koKR", function() return {
	["Healing taken"] = "받은 치유량",
} end)

L:RegisterTranslations("frFR", function() return {
	["Healing taken"] = "Soins reçus",
	["HT"] = "SR",
} end)

-----------------------------------------------------------------------
-- Locals
-----------------------------------------------------------------------

local moduleName = "Healing taken"
local roster = AceLibrary("Roster-2.1")
local parserEvent = {
	eventType = "Heal",
	recipientID_not = false,	
}

-----------------------------------------------------------------------
-- Module declaration
-----------------------------------------------------------------------

local mod = Violation:NewModule(moduleName)
mod.revision = tonumber(("$Revision: 60394 $"):sub(12, -3)) or 1
mod.version = 5
mod.violationCategory = "healing"

-----------------------------------------------------------------------
-- Module initialization
-----------------------------------------------------------------------

function mod:OnModuleEnable()
	self:RegisterParserEvent( parserEvent, "OnParserEvent" )
end

-----------------------------------------------------------------------
-- Module implementation
-----------------------------------------------------------------------

function mod:GetDisplayName() return L["Healing taken"] end
function mod:GetShortDisplayName() return L["HT"] end

local function getOverheal( unit, amount )
	local overheal = 0
	if unit and UnitExists(unit) then
		local d = UnitHealthMax(unit)-UnitHealth(unit)
		if d < amount then
			overheal = amount - d
		end
	end
	return overheal
end

function mod:OnParserEvent( info )
	local victim, amount = select(2, self:GetSourceVictimAmount(info))
	
	if not victim or amount == 0 or not self:AcceptDataFor( victim ) then
		return
	end

	local victimid = roster:GetUnitIDFromName( victim )
	amount = amount - getOverheal( victimid, amount )
	self:OnData(victim, amount)
end
