﻿-----------------------------------------------------------------------
-- Locale
-----------------------------------------------------------------------
local L = AceLibrary("AceLocale-2.2"):new("Violation: Overhealing")

L:RegisterTranslations("enUS", function() return {
	["Overhealing done"] = true,
	["OH"] = true,
} end)

L:RegisterTranslations("zhCN", function() return {
	["Overhealing done"] = "过量治疗",
	["OH"] = "过量治疗(OH)",	
} end)

L:RegisterTranslations("zhTW", function() return {
	["Overhealing done"] = "過量治療",
	["OH"] = "過量治療(OH)",	
} end)

L:RegisterTranslations("koKR", function() return {
	["Overhealing done"] = "오버힐량",
} end)

L:RegisterTranslations("frFR", function() return {
	["Overhealing done"] = "Soins en excès",
	["OH"] = "SE",
} end)

-----------------------------------------------------------------------
-- Locals
-----------------------------------------------------------------------

local roster = AceLibrary("Roster-2.1")
local parserEvent = {
	sourceID_not = false,
	eventType = "Heal",
}

-----------------------------------------------------------------------
-- Locals for  module
-----------------------------------------------------------------------

local moduleName = "Overhealing done"

-----------------------------------------------------------------------
-- Module declaration
-----------------------------------------------------------------------

local mod = Violation:NewModule(moduleName)
mod.revision = tonumber(("$Revision: 60394 $"):sub(12, -3)) or 1
mod.version = 5
mod.violationCategory = "healing"

-----------------------------------------------------------------------
-- Module initialization
-----------------------------------------------------------------------

function mod:OnModuleEnable()
	self:RegisterParserEvent(parserEvent, "OnParserEvent")
end

-----------------------------------------------------------------------
-- Module implementation
-----------------------------------------------------------------------

function mod:GetDisplayName() return L["Overhealing done"] end
function mod:GetShortDisplayName() return L["OH"] end
local function getOverheal( unit, amount )
	local overheal = 0
	if unit and UnitExists(unit) then
		local d = UnitHealthMax(unit)-UnitHealth(unit)
		if d < amount then
			overheal = amount - d
		end
	end
	return overheal
end

function mod:OnParserEvent( info )
	local source, victim, amount = self:GetSourceVictimAmount(info)
	
	if not source or not victim or amount == 0 or not self:AcceptDataFor( source ) then
		return
	end

	local victimid = roster:GetUnitIDFromName( victim )
	self:OnData(source, getOverheal( victimid, amount ))
end
